@@ -86,12 +86,13 @@ class AudioClip(Clip):
                       codec, bitrate, verbose)
 
 try:
-    # Add methods preview (only if pygame installed)
+    
+    # Add method preview (only if pygame installed)
     from moviepy.audio.io.preview import preview
     AudioClip.preview = preview
+    
 except:
     pass
-from moviepy.audio.io.preview import preview
         
 
 class AudioArrayClip(AudioClip):
@@ -131,7 +132,6 @@ class AudioArrayClip(AudioClip):
         self.get_frame = gf
         
         
-        
 class CompositeAudioClip(AudioClip):
 
     """
